==> open-xchange-documents-backend_7.10.0.orig.tar.bz2: open-xchange-documents-backend-7.10.0/com.openexchange.office.rest/src/com/openexchange/office/rest/RenameDocumentAction.java <==

package com.openexchange.office.rest;

import org.json.JSONObject;

import com.openexchange.ajax.requesthandler.AJAXRequestData;
import com.openexchange.ajax.requesthandler.AJAXRequestResult;
import com.openexchange.office.tools.rest.RequestDataHelper;
import com.openexchange.server.ServiceLookup;
import com.openexchange.tools.session.ServerSession;

/**
 * {@link RenameDocumentAction}
 *
 * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
 */

/*
 * MH/KA compilefix for buildsystem
 * @Action(method = RequestMethod.GET, name = "renamedocument", description = "Set a new filename for the given filestore document.",
 * parameters = {
 * @Parameter(name = "file_id", description = "Object ID of the requested infoitem."),
 * @Parameter(name = "target_filename", description = "The new filename of the requested filestore item to be set."),
 * @Parameter(name = "session", description = "A session ID previously obtained from the login module."),
 * @Parameter(name = "uid", description = "The unique id of the client application."),
 * @Parameter(name = "version", optional=true, description =
 * "If present, the infoitem data describes the given version. Otherwise the current version is returned.") }, responseDescription =
 * "Response with timestamp: A JSON object containing the attributes of the created filestore item: 'id', 'folder_id', 'version' and 'filename'."
 * )
 */

public class RenameDocumentAction extends DocumentRESTAction {
  
    /**
     * Initializes a new {@link RenameDocumentAction}.
     * @param services
     */
    public RenameDocumentAction(ServiceLookup servicesDEPRECATED) {
        super(null);
    }

    /* (non-Javadoc)
     * @see com.openexchange.ajax.requesthandler.AJAXActionService#perform(com.openexchange.ajax.requesthandler.AJAXRequestData, com.openexchange.tools.session.ServerSession)
     */
    @Override
    public AJAXRequestResult perform(AJAXRequestData request, ServerSession session) {
        final JSONObject requestData = new JSONObject();
     
        RequestDataHelper.mapOfficeParamsToNormalParam(request, session, null, requestData);

        return getAjaxRequestResult(sendConnectionMessageSynchronously(request, session, "renameDocument", "document", requestData));
    }
}

==> open-xchange-documents-backend_7.10.1.orig.tar.bz2: open-xchange-documents-backend-7.10.1/com.openexchange.office.rest/src/com/openexchange/office/rest/RenameDocumentAction.java <==

package com.openexchange.office.rest;

import org.apache.commons.lang3.StringUtils;
import org.apache.commons.logging.Log;
import org.json.JSONObject;

import com.openexchange.ajax.requesthandler.AJAXRequestData;
import com.openexchange.ajax.requesthandler.AJAXRequestResult;
import com.openexchange.office.rest.tools.HttpStatusCode;
import com.openexchange.office.rest.tools.ParamValidator;
import com.openexchange.office.rest.tools.SessionIdCheck;
import com.openexchange.office.tools.rest.RequestDataHelper;
import com.openexchange.server.ServiceLookup;
import com.openexchange.tools.session.ServerSession;

/**
 * {@link RenameDocumentAction}
 *
 * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
 */

/*
 * MH/KA compilefix for buildsystem
 * @Action(method = RequestMethod.GET, name = "renamedocument", description = "Set a new filename for the given filestore document.",
 * parameters = {
 * @Parameter(name = "file_id", description = "Object ID of the requested infoitem."),
 * @Parameter(name = "target_filename", description = "The new filename of the requested filestore item to be set."),
 * @Parameter(name = "session", description = "A session ID previously obtained from the login module."),
 * @Parameter(name = "uid", description = "The unique id of the client application."),
 * @Parameter(name = "version", optional=true, description =
 * "If present, the infoitem data describes the given version. Otherwise the current version is returned.") }, responseDescription =
 * "Response with timestamp: A JSON object containing the attributes of the created filestore item: 'id', 'folder_id', 'version' and 'filename'."
 * )
 */

public class RenameDocumentAction extends DocumentRESTAction {

    @SuppressWarnings("deprecation")
    private static final Log LOG = com.openexchange.log.Log.loggerFor(RenameDocumentAction.class);

    /**
     * Initializes a new {@link RenameDocumentAction}.
     * @param services
     */
    public RenameDocumentAction(ServiceLookup servicesDEPRECATED) {
        super(null);
    }

    /* (non-Javadoc)
     * @see com.openexchange.ajax.requesthandler.AJAXActionService#perform(com.openexchange.ajax.requesthandler.AJAXRequestData, com.openexchange.tools.session.ServerSession)
     */
    @Override
    public AJAXRequestResult perform(AJAXRequestData request, ServerSession session) {
        final JSONObject requestData = new JSONObject();

        // #60801: we need to check for an illegal CSRF attempt by checking the
        // correct sessionId; set errorcode to 400 in case of an invalid request
        if (SessionIdCheck.isNotValid(request.getParameter("session"), session)) {
            LOG.warn("RenameDocumentAction detected invalid session id - request rejected!");
            return ParamValidator.getResultFor(HttpStatusCode.BAD_REQUEST.getStatusCode());
        }

        RequestDataHelper.mapOfficeParamsToNormalParam(request, session, null, requestData);

        return getAjaxRequestResult(sendConnectionMessageSynchronously(request, session, "renameDocument", "document", requestData));
    }
}
